==> mingw-w64-aws-sdk-cpp-1.9.377-1.src.tar.zst: aws-sdk-cpp-1.9.377/aws-cpp-sdk-sesv2/source/model/GetConfigurationSetResult.cpp <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/sesv2/model/GetConfigurationSetResult.h>
#include <aws/core/utils/json/JsonSerializer.h>
#include <aws/core/AmazonWebServiceResult.h>
#include <aws/core/utils/StringUtils.h>
#include <aws/core/utils/UnreferencedParam.h>

#include <utility>

using namespace Aws::SESV2::Model;
using namespace Aws::Utils::Json;
using namespace Aws::Utils;
using namespace Aws;

GetConfigurationSetResult::GetConfigurationSetResult()
{
}

GetConfigurationSetResult::GetConfigurationSetResult(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  *this = result;
}

GetConfigurationSetResult& GetConfigurationSetResult::operator =(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  JsonView jsonValue = result.GetPayload().View();
  if(jsonValue.ValueExists("ConfigurationSetName"))
  {
    m_configurationSetName = jsonValue.GetString("ConfigurationSetName");

  }

  if(jsonValue.ValueExists("TrackingOptions"))
  {
    m_trackingOptions = jsonValue.GetObject("TrackingOptions");

  }

  if(jsonValue.ValueExists("DeliveryOptions"))
  {
    m_deliveryOptions = jsonValue.GetObject("DeliveryOptions");

  }

  if(jsonValue.ValueExists("ReputationOptions"))
  {
    m_reputationOptions = jsonValue.GetObject("ReputationOptions");

  }

  if(jsonValue.ValueExists("SendingOptions"))
  {
    m_sendingOptions = jsonValue.GetObject("SendingOptions");

  }

  if(jsonValue.ValueExists("Tags"))
  {
    Array<JsonView> tagsJsonList = jsonValue.GetArray("Tags");
    for(unsigned tagsIndex = 0; tagsIndex < tagsJsonList.GetLength(); ++tagsIndex)
    {
      m_tags.push_back(tagsJsonList[tagsIndex].AsObject());
    }
  }

  if(jsonValue.ValueExists("SuppressionOptions"))
  {
    m_suppressionOptions = jsonValue.GetObject("SuppressionOptions");

  }

  if(jsonValue.ValueExists("VdmOptions"))
  {
    m_vdmOptions = jsonValue.GetObject("VdmOptions");

  }



  return *this;
}

==> mingw-w64-aws-sdk-cpp-1.10.9-1.src.tar.zst: aws-sdk-cpp-1.10.9/aws-cpp-sdk-sesv2/source/model/GetConfigurationSetResult.cpp <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/sesv2/model/GetConfigurationSetResult.h>
#include <aws/core/utils/json/JsonSerializer.h>
#include <aws/core/AmazonWebServiceResult.h>
#include <aws/core/utils/StringUtils.h>
#include <aws/core/utils/UnreferencedParam.h>

#include <utility>

using namespace Aws::SESV2::Model;
using namespace Aws::Utils::Json;
using namespace Aws::Utils;
using namespace Aws;

GetConfigurationSetResult::GetConfigurationSetResult()
{
}

GetConfigurationSetResult::GetConfigurationSetResult(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  *this = result;
}

GetConfigurationSetResult& GetConfigurationSetResult::operator =(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  JsonView jsonValue = result.GetPayload().View();
  if(jsonValue.ValueExists("ConfigurationSetName"))
  {
    m_configurationSetName = jsonValue.GetString("ConfigurationSetName");

  }

  if(jsonValue.ValueExists("TrackingOptions"))
  {
    m_trackingOptions = jsonValue.GetObject("TrackingOptions");

  }

  if(jsonValue.ValueExists("DeliveryOptions"))
  {
    m_deliveryOptions = jsonValue.GetObject("DeliveryOptions");

  }

  if(jsonValue.ValueExists("ReputationOptions"))
  {
    m_reputationOptions = jsonValue.GetObject("ReputationOptions");

  }

  if(jsonValue.ValueExists("SendingOptions"))
  {
    m_sendingOptions = jsonValue.GetObject("SendingOptions");

  }

  if(jsonValue.ValueExists("Tags"))
  {
    Aws::Utils::Array<JsonView> tagsJsonList = jsonValue.GetArray("Tags");
    for(unsigned tagsIndex = 0; tagsIndex < tagsJsonList.GetLength(); ++tagsIndex)
    {
      m_tags.push_back(tagsJsonList[tagsIndex].AsObject());
    }
  }

  if(jsonValue.ValueExists("SuppressionOptions"))
  {
    m_suppressionOptions = jsonValue.GetObject("SuppressionOptions");

  }

  if(jsonValue.ValueExists("VdmOptions"))
  {
    m_vdmOptions = jsonValue.GetObject("VdmOptions");

  }



  return *this;
}
